@@ -112,8 +112,8 @@ class Witter():
             "on_trend_clicked" : self.switchView,
             "on_insert_clicked" : self.twitPic,
             "on_friends_clicked" : self.switchView,
-	    "on_cancel_clicked" : self.gtk_widget_hide,
 	    "setProps" : self.setProps,
+	    "nosetProps" : self.dontsetProps,
         }
         self.builder.connect_signals(dic)
         #self.wTree.signal_autoconnect( dic )
@@ -128,6 +128,8 @@ class Witter():
 	friendsButton = self.builder.get_object("friends")
 	okButton = self.builder.get_object("Ok")
 	cancelButton = self.builder.get_object("Cancel")
+	propscancelButton = self.builder.get_object("props-cancel")
+	refreshstoreButton = self.builder.get_object("refresh_store")
 	refreshButton.set_name("HildonButton-finger")
 	tweetButton.set_name("HildonButton-finger")
 	timelineButton.set_name("HildonButton-finger")
@@ -137,6 +139,8 @@ class Witter():
 	friendsButton.set_name("HildonButton-finger")
 	okButton.set_name("HildonButton-finger")
 	cancelButton.set_name("HildonButton-finger")
+	propscancelButton.set_name("HildonButton-finger")
+	refreshstoreButton.set_name("HildonButton-finger")
 	
 	self.textcolour="#FFFFFF"
         #
@@ -277,7 +281,8 @@ class Witter():
 
         # self.treeview.connect("changed", self.build_menu, None);
         self.treeview.tap_and_hold_setup(self.urlmenu, callback=gtk.tap_and_hold_menu_position_top)
-	
+	#init the configDialog
+	self.configDialog = None
         if (re.search("UserName",self.username)):
 	       self.promptForCredentials() 
 	#call the refresh thread
@@ -1344,7 +1349,7 @@ class Witter():
         dialog = self.builder.get_object("CredentialsDialog")
         dialog.set_title("Twitter Credentials")
         dialog.connect("response", self.gtk_widget_hide)
-        dialog.show()
+        dialog.show_all()
         
     def  store_creds(self, widget, *args):
         print "store_creds called"
@@ -1355,8 +1360,9 @@ class Witter():
         self.writeConfig()
 
     def  gtk_widget_hide(self, widget, *args):
-        widget.hide()
-        
+        widget.hide_all()
+        #widget.destroy()
+	
     def reparent_loc(self, widget, newParent):
         widget.reparent(newParent)
         
@@ -1539,20 +1545,27 @@ class Witter():
 	
     def configProperties(self, widget, *args):
 	    #dialog = self.wTree.get_widget("CredentialsDialog")
-	    dialog = self.builder.get_object("setRefreshDialog")
-            dialog.set_title("Witter Properties")
-            dialog.connect("response", self.gtk_widget_hide)
-	    self.timelineNumberEd = self.builder.get_object("timeline-NumberEditor")
+	    if (self.configDialog == None):
+		self.configDialog = self.builder.get_object("setRefreshDialog")
+		self.configDialog.set_title("Witter Properties")
+		self.configDialog.connect("response", self.dontsetProps)
+	    
+		self.timelineNumberEd = self.builder.get_object("timeline-NumberEditor")
+		self.mentionsNumberEd = self.builder.get_object("mentions-NumberEditor")
+		self.DMNumberEd = self.builder.get_object("DM-NumberEditor")
+		self.publicNumberEd = self.builder.get_object("public-NumberEditor")
+	    
 	    self.timelineNumberEd.set_value(self.timelineRefresh)
-	    self.mentionsNumberEd = self.builder.get_object("mentions-NumberEditor")
 	    self.mentionsNumberEd.set_value(self.mentionsRefresh)
-	    self.DMNumberEd = self.builder.get_object("DM-NumberEditor")
 	    self.DMNumberEd.set_value(self.DMsRefresh)
-	    self.publicNumberEd = self.builder.get_object("public-NumberEditor")
 	    self.publicNumberEd.set_value(self.publicRefresh)
 	
-            dialog.show()
+            self.configDialog.show_all()
 
+    def dontsetProps(self,widget, *args):
+	    print "cancelledOperation"
+	    self.configDialog.hide_all()
+	    
     def setProps(self, widget, *args):
 	    #set all the refresh inteval values
 	    self.timelineRefresh = self.timelineNumberEd.get_value()
@@ -1562,6 +1575,7 @@ class Witter():
 	    #stop and start the threads to pick up the new values
 	    self.end_refresh_threads()
 	    self.start_refresh_threads()
+	    self.configDialog.hide_all()
 	    
     def end_refresh_threads(self):
 	    #end all the refresh threads
